==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm5/lib/AverageTrueRangeIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { AverageTrueRangeIndicatorStrategy } from "./AverageTrueRangeIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var AverageTrueRangeIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AverageTrueRangeIndicator, _super);
    function AverageTrueRangeIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AverageTrueRangeIndicator.prototype.get_up = function () {
        return new AverageTrueRangeIndicatorStrategy();
    };
    Object.defineProperty(AverageTrueRangeIndicator.prototype, "up", {
        get: function () {
            return this.get_up();
        },
        enumerable: false,
        configurable: true
    });
    AverageTrueRangeIndicator.prototype.get_u2 = function () {
        return AverageTrueRangeIndicator.$;
    };
    Object.defineProperty(AverageTrueRangeIndicator.prototype, "u2", {
        get: function () {
            return this.get_u2();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(AverageTrueRangeIndicator.prototype, "va", {
        get: function () {
            return typeGetValue(this.c(AverageTrueRangeIndicator.vb));
        },
        set: function (a) {
            this.h(AverageTrueRangeIndicator.vb, a);
        },
        enumerable: false,
        configurable: true
    });
    AverageTrueRangeIndicator.prototype.uv = function () {
        return this.va;
    };
    AverageTrueRangeIndicator.prototype.u4 = function (a) {
        this.va = a;
    };
    AverageTrueRangeIndicator.$t = markType(AverageTrueRangeIndicator, 'AverageTrueRangeIndicator', StrategyBasedIndicator.$);
    AverageTrueRangeIndicator.vb = StrategyBasedIndicator.u7(14, AverageTrueRangeIndicator.$);
    return AverageTrueRangeIndicator;
}(StrategyBasedIndicator));
export { AverageTrueRangeIndicator };

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm5/lib/AverageTrueRangeIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { AverageTrueRangeIndicatorStrategy } from "./AverageTrueRangeIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var AverageTrueRangeIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AverageTrueRangeIndicator, _super);
    function AverageTrueRangeIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AverageTrueRangeIndicator.prototype.get_yy = function () {
        return new AverageTrueRangeIndicatorStrategy();
    };
    Object.defineProperty(AverageTrueRangeIndicator.prototype, "yy", {
        get: function () {
            return this.get_yy();
        },
        enumerable: false,
        configurable: true
    });
    AverageTrueRangeIndicator.prototype.get_zb = function () {
        return AverageTrueRangeIndicator.$;
    };
    Object.defineProperty(AverageTrueRangeIndicator.prototype, "zb", {
        get: function () {
            return this.get_zb();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(AverageTrueRangeIndicator.prototype, "zj", {
        get: function () {
            return typeGetValue(this.c(AverageTrueRangeIndicator.zk));
        },
        set: function (a) {
            this.h(AverageTrueRangeIndicator.zk, a);
        },
        enumerable: false,
        configurable: true
    });
    AverageTrueRangeIndicator.prototype.y4 = function () {
        return this.zj;
    };
    AverageTrueRangeIndicator.prototype.zd = function (a) {
        this.zj = a;
    };
    AverageTrueRangeIndicator.$t = markType(AverageTrueRangeIndicator, 'AverageTrueRangeIndicator', StrategyBasedIndicator.$);
    AverageTrueRangeIndicator.zk = StrategyBasedIndicator.zg(14, AverageTrueRangeIndicator.$);
    return AverageTrueRangeIndicator;
}(StrategyBasedIndicator));
export { AverageTrueRangeIndicator };
